@@ -15,16 +15,7 @@
  */
 
 #ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
-/**
- * Description:
- *   This header contains the exported interface of the Job Management.
- *
- * CVS Information:
- * $Source: /home/globdev/CVS/globus-packages/gram/jobmanager/source/globus_gram_job_manager.h,v $
- * $Date: 2012/06/18 16:44:17 $
- * $Revision: 1.70.2.9 $
- * $Author: bester $
- */
+
 #ifndef GLOBUS_GRAM_JOB_MANAGER_INCLUDE
 #define GLOBUS_GRAM_JOB_MANAGER_INCLUDE
 
@@ -39,7 +30,9 @@
 
 #define GLOBUS_GRAM_AUTHZ_CALLOUT_TYPE "globus_gram_jobmanager_authz"
 
-EXTERN_C_BEGIN
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 #define GLOBUS_GRAM_JOB_MANAGER_EXPIRATION_ATTR "expiration"
 
@@ -911,6 +904,7 @@ globus_gram_job_manager_request_init(
     char *                              rsl,
     gss_cred_id_t                       delegated_credential,
     gss_ctx_id_t                        response_ctx,
+    const char *                        peer_address,
     globus_gsi_cred_handle_t            peer_cred,
     globus_bool_t                       reinit,
     char **                             old_job_contact,
@@ -1656,7 +1650,11 @@ char *
 globus_gram_prepare_log_string(
     const char *                        instr);
 
-EXTERN_C_END
+extern char globus_i_gram_default_rvf[];
+
+#ifdef __cplusplus
+}
+#endif
 
 #endif /* GLOBUS_GRAM_JOB_MANAGER_INCLUDE */
 #endif /* ! GLOBUS_DONT_DOCUMENT_INTERNAL */
